# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Card(Component):
    """A Card component.


Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- buttonText (string; optional):
    The text for the button.

- content (string; optional):
    The content of the card.

- n_clicks (number; default 0):
    Number of times the button has been clicked.

- subtitle (string; optional):
    The subtitle of the card.

- title (string; optional):
    The title of the card.

- topic (string; optional):
    The topic of the card."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Card'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, topic=Component.UNDEFINED, title=Component.UNDEFINED, subtitle=Component.UNDEFINED, content=Component.UNDEFINED, buttonText=Component.UNDEFINED, n_clicks=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'buttonText', 'content', 'n_clicks', 'subtitle', 'title', 'topic']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'buttonText', 'content', 'n_clicks', 'subtitle', 'title', 'topic']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Card, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Form(Component):
    """A Form component.
Form component using Material-UI.
It creates a form with text fields and select fields based on the provided configuration.

Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- fields (list of dicts; optional):
    A list of field objects to be rendered in the Form. Each object
    should have properties like 'id', 'label', 'type', etc.

    `fields` is a list of dicts with keys:

    - defaultValue (string; optional)

    - disabled (boolean; optional)

    - helperText (string; optional)

    - id (string; required)

    - label (string; required)

    - native (boolean; optional)

    - options (list of dicts; optional)

        `options` is a list of dicts with keys:

        - label (string; required)

        - value (string; required)

    - readOnly (boolean; optional)

    - required (boolean; optional)

    - shrinkLabel (boolean; optional)

    - type (string; optional)

    - variant (a value equal to: 'outlined', 'filled', 'standard'; optional)

- values (dict; optional):
    An object containing the current values of the form fields. Keys
    are field IDs and values are the current values."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Form'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, fields=Component.UNDEFINED, values=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'fields', 'values']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'fields', 'values']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Form, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Select(Component):
    """A Select component.
Select component using Material-UI.
It allows selecting from multiple options.
The 'id' prop is required.

Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- disabled (boolean; default False):
    If True, the select is disabled.

- error (boolean; default False):
    If True, the select displays an error.

- helperText (string; default ''):
    Optional helper text to display below the select.

- label (string; optional):
    The label for the select input.

- options (list of dicts; required):
    The available options for the select.

    `options` is a list of dicts with keys:

    - label (string; required)

    - value (string; required)

- readOnly (boolean; default False):
    If True, the select is read-only.

- required (boolean; default False):
    If True, the select input is required.

- value (string; default ''):
    The currently selected value."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Select'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, label=Component.UNDEFINED, value=Component.UNDEFINED, options=Component.REQUIRED, disabled=Component.UNDEFINED, error=Component.UNDEFINED, readOnly=Component.UNDEFINED, required=Component.UNDEFINED, helperText=Component.UNDEFINED, onChange=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'disabled', 'error', 'helperText', 'label', 'options', 'readOnly', 'required', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'disabled', 'error', 'helperText', 'label', 'options', 'readOnly', 'required', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id', 'options']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Select, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Backdrop(Component):
    """A Backdrop component.
Backdrop component using Material-UI.
It shows an overlay backdrop, useful for loading or other UI feedback.

Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- invisible (boolean; default False):
    If True, the backdrop is invisible.

- open (boolean; default False):
    If True, the backdrop is open."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Backdrop'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, open=Component.UNDEFINED, invisible=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'invisible', 'open']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'invisible', 'open']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Backdrop, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Table(Component):
    """A Table component.
Table is a component that displays data in a tabular format.
It takes a property `data` which is an array of objects representing the table rows.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- data (list of dicts; optional):
    The data to be displayed in the table. It should be an array of
    objects, where each object represents a row.

- dense (boolean; default False):
    If True, the table will be rendered in a dense layout.

- stickyHeader (boolean; default False):
    If True, the table header will be sticky."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Table'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.UNDEFINED, dense=Component.UNDEFINED, stickyHeader=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'data', 'dense', 'stickyHeader']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'data', 'dense', 'stickyHeader']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Table, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ButtonGroup(Component):
    """A ButtonGroup component.
ButtonGroup component using Material-UI.
It provides a group of buttons with customizable variant, size, color, orientation, and aria-label.
The component updates a property with the ID of the last clicked button.

Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- ariaLabel (string; default 'button group'):
    The aria-label for the ButtonGroup.

- buttons (list of dicts; optional):
    A list of button objects to be rendered in the ButtonGroup. Each
    object should have 'id' and 'label' properties.

    `buttons` is a list of dicts with keys:

    - id (string; required)

    - label (string; required)

- color (a value equal to: 'primary', 'secondary', 'error', 'info', 'success', 'warning'; default 'primary'):
    The color of the ButtonGroup.

- lastClicked (string; optional):
    The ID of the last clicked button.

- orientation (a value equal to: 'horizontal', 'vertical'; default 'horizontal'):
    The orientation of the ButtonGroup.

- size (a value equal to: 'small', 'medium', 'large'; default 'medium'):
    The size of the ButtonGroup.

- variant (a value equal to: 'text', 'outlined', 'contained'; default 'contained'):
    The variant to use for the ButtonGroup."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'ButtonGroup'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, variant=Component.UNDEFINED, size=Component.UNDEFINED, color=Component.UNDEFINED, orientation=Component.UNDEFINED, ariaLabel=Component.UNDEFINED, buttons=Component.UNDEFINED, lastClicked=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'ariaLabel', 'buttons', 'color', 'lastClicked', 'orientation', 'size', 'variant']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'ariaLabel', 'buttons', 'color', 'lastClicked', 'orientation', 'size', 'variant']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(ButtonGroup, self).__init__(**args)



from .Accordion import Accordion
from .Alert import Alert
from .App import App
from .AppBar import AppBar
from .Backdrop import Backdrop
from .Button import Button
from .ButtonGroup import ButtonGroup
from .Card import Card
from .CheckBoxTable import CheckBoxTable
from .Form import Form
from .Grid import Grid
from .Item import Item
from .Menu import Menu
from .Pagination import Pagination
from .Paper import Paper
from .RadioGroup import RadioGroup
from .Select import Select
from .Slider import Slider
from .Switch import Switch
from .Table import Table

__all__ = [
    "Accordion",
    "Alert",
    "App",
    "AppBar",
    "Backdrop",
    "Button",
    "ButtonGroup",
    "Card",
    "CheckBoxTable",
    "Form",
    "Grid",
    "Item",
    "Menu",
    "Pagination",
    "Paper",
    "RadioGroup",
    "Select",
    "Slider",
    "Switch",
    "Table"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Switch(Component):
    """A Switch component.


Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- checked (boolean; default False):
    If True, the switch is checked.

- color (a value equal to: 'default', 'primary', 'secondary', 'error', 'info', 'success', 'warning'; optional):
    The color of the component.

- disabled (boolean; optional):
    If True, the switch will be disabled.

- size (a value equal to: 'small', 'medium'; optional):
    The size of the component."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Switch'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, checked=Component.UNDEFINED, disabled=Component.UNDEFINED, color=Component.UNDEFINED, size=Component.UNDEFINED, onChange=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'checked', 'color', 'disabled', 'size']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'checked', 'color', 'disabled', 'size']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Switch, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Button(Component):
    """A Button component.
Button component using Material-UI.
It can be customized with various optional props to change its appearance and behavior.
The 'id' prop is required.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The content of the button.

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- color (a value equal to: 'inherit', 'primary', 'secondary', 'success', 'error', 'info', 'warning'; optional):
    The color of the component.

- disabled (boolean; optional):
    If True, the button will be disabled.

- endIcon (string; optional):
    Icon placed after the children. Should be a string matching an
    icon name from @mui/icons-material.

- fullWidth (boolean; optional):
    If True, the button will take up the full width of its container.

- href (string; optional):
    The URL to link to when the button is clicked.

- n_clicks (number; default 0):
    Number of times the button has been clicked.

- size (a value equal to: 'small', 'medium', 'large'; optional):
    The size of the component.

- startIcon (string; optional):
    Icon placed before the children. Should be a string matching an
    icon name from @mui/icons-material.

- variant (a value equal to: 'text', 'outlined', 'contained'; optional):
    The variant to use."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Button'
    @_explicitize_args
    def __init__(self, children=None, id=Component.REQUIRED, variant=Component.UNDEFINED, color=Component.UNDEFINED, size=Component.UNDEFINED, disabled=Component.UNDEFINED, fullWidth=Component.UNDEFINED, href=Component.UNDEFINED, startIcon=Component.UNDEFINED, endIcon=Component.UNDEFINED, n_clicks=Component.UNDEFINED, onClick=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'color', 'disabled', 'endIcon', 'fullWidth', 'href', 'n_clicks', 'size', 'startIcon', 'variant']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'color', 'disabled', 'endIcon', 'fullWidth', 'href', 'n_clicks', 'size', 'startIcon', 'variant']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Button, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Pagination(Component):
    """A Pagination component.


Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- boundaryCount (number; default 1):
    Number of always visible pages at the beginning and end.

- color (a value equal to: 'standard', 'primary', 'secondary'; default 'standard'):
    The color of the component.

- count (number; default 1):
    The total number of pages.

- defaultPage (number; default 1):
    The default page number (uncontrolled component).

- disabled (boolean; default False):
    If True, the pagination component will be disabled.

- hideNextButton (boolean; default False):
    If True, hide the next-page button.

- hidePrevButton (boolean; default False):
    If True, hide the previous-page button.

- page (number; default 1):
    The current page number.

- shape (a value equal to: 'circular', 'rounded'; default 'circular'):
    The shape of the pagination items.

- showFirstButton (boolean; default False):
    If True, show the first-page button.

- showLastButton (boolean; default False):
    If True, show the last-page button.

- siblingCount (number; default 1):
    Number of always visible pages before and after the current page.

- size (a value equal to: 'small', 'medium', 'large'; default 'medium'):
    The size of the pagination component.

- variant (a value equal to: 'text', 'outlined'; default 'text'):
    The variant to use."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Pagination'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, count=Component.UNDEFINED, page=Component.UNDEFINED, defaultPage=Component.UNDEFINED, siblingCount=Component.UNDEFINED, boundaryCount=Component.UNDEFINED, variant=Component.UNDEFINED, shape=Component.UNDEFINED, size=Component.UNDEFINED, color=Component.UNDEFINED, disabled=Component.UNDEFINED, showFirstButton=Component.UNDEFINED, showLastButton=Component.UNDEFINED, hidePrevButton=Component.UNDEFINED, hideNextButton=Component.UNDEFINED, onChange=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'boundaryCount', 'color', 'count', 'defaultPage', 'disabled', 'hideNextButton', 'hidePrevButton', 'page', 'shape', 'showFirstButton', 'showLastButton', 'siblingCount', 'size', 'variant']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'boundaryCount', 'color', 'count', 'defaultPage', 'disabled', 'hideNextButton', 'hidePrevButton', 'page', 'shape', 'showFirstButton', 'showLastButton', 'siblingCount', 'size', 'variant']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Pagination, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Grid(Component):
    """A Grid component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The content of the layout.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- direction (a value equal to: 'row', 'row-reverse', 'column', 'column-reverse'; default 'row'):
    Defines the `flex-direction` style property.

- spacing (number; default 3):
    Defines the space between the type `item` components."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Grid'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, spacing=Component.UNDEFINED, direction=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'direction', 'spacing']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'direction', 'spacing']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(Grid, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Menu(Component):
    """A Menu component.


Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- buttonText (string; default 'Open Menu'):
    The text displayed on the button that opens the menu.

- menuItems (list of dicts; optional):
    Array of menu item labels or objects.

    `menuItems` is a list of string | dict with keys:

    - disabled (boolean; optional)

    - icon (string; optional)

    - label (string; required)s

- selectedIndex (number; optional):
    Index of the selected menu item."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Menu'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, buttonText=Component.UNDEFINED, menuItems=Component.UNDEFINED, onItemClick=Component.UNDEFINED, selectedIndex=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'buttonText', 'menuItems', 'selectedIndex']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'buttonText', 'menuItems', 'selectedIndex']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Menu, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Accordion(Component):
    """An Accordion component.


Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- panels (list of dicts; optional):
    An array of panel objects to be rendered in the accordion.

    `panels` is a list of dicts with keys:

    - actions (list of dicts; optional)

        `actions` is a list of dicts with keys:

        - label (string; required)

        - onClick (optional)

    - defaultExpanded (boolean; optional)

    - details (string; required)

    - expanded (boolean; optional)

    - id (string; required)

    - summary (string; required)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Accordion'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, panels=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'panels']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'panels']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Accordion, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Paper(Component):
    """A Paper component.
Paper component using Material-UI.
It can be customized with various optional props like elevation and variant.
The 'id' prop is required for Dash callbacks.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The content of the Paper component.

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- elevation (number; default 1):
    The elevation of the Paper component. Accepts values from 0 to 24.

- variant (a value equal to: 'elevation', 'outlined'; default 'elevation'):
    The variant to use. Either 'elevation' or 'outlined'."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Paper'
    @_explicitize_args
    def __init__(self, children=None, id=Component.REQUIRED, elevation=Component.UNDEFINED, variant=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'elevation', 'variant']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'elevation', 'variant']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Paper, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Alert(Component):
    """An Alert component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The main content displayed in the alert.

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- action (a list of or a singular dash component, string or number; optional):
    The action to display. It renders after the message, at the end of
    the alert.

- open (boolean; default True):
    If True, the alert is displayed.

- severity (a value equal to: 'error', 'warning', 'info', 'success'; default 'success'):
    The severity of the alert.

- variant (a value equal to: 'standard', 'filled', 'outlined'; default 'standard'):
    The variant to use."""
    _children_props = ['action']
    _base_nodes = ['action', 'children']
    _namespace = 'dash_material_ui'
    _type = 'Alert'
    @_explicitize_args
    def __init__(self, children=None, id=Component.REQUIRED, severity=Component.UNDEFINED, variant=Component.UNDEFINED, onClose=Component.UNDEFINED, action=Component.UNDEFINED, open=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'action', 'open', 'severity', 'variant']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'action', 'open', 'severity', 'variant']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Alert, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AppBar(Component):
    """An AppBar component.
AppBar component using Material-UI.
It provides a header with customizable title, menu button, and navigation sections.

Keyword arguments:

- id (string; required):
    The ID used to identify this component in Dash callbacks.

- color (a value equal to: 'default', 'primary', 'secondary', 'inherit', 'transparent'; default 'primary'):
    The color of the AppBar.

- position (a value equal to: 'fixed', 'absolute', 'sticky', 'static', 'relative'; default 'static'):
    The position of the AppBar.

- sections (dict with strings as keys and values of type string; optional):
    A dictionary of sections to be displayed in the AppBar. The keys
    are the section names and the values are the section paths.

- showMenuButton (boolean; default True):
    Whether to show the menu button.

- title (string; default 'App Bar'):
    The title to be displayed in the AppBar."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'AppBar'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, title=Component.UNDEFINED, showMenuButton=Component.UNDEFINED, position=Component.UNDEFINED, color=Component.UNDEFINED, sections=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'color', 'position', 'sections', 'showMenuButton', 'title']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'color', 'position', 'sections', 'showMenuButton', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(AppBar, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Slider(Component):
    """A Slider component.


Keyword arguments:

- id (string; default ''):
    The ID used to identify this component in Dash callbacks.

- ariaLabel (string; default 'Slider'):
    The aria-label for the slider.

- defaultValue (number; default 30):
    The default value of the slider.

- disabled (boolean; default False):
    If True, the slider will be disabled.

- max (number; default 100):
    The maximum allowed value of the slider.

- min (number; default 0):
    The minimum allowed value of the slider.

- step (number; default 1):
    The step interval of the slider.

- value (number; default undefined):
    The current value of the slider."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_material_ui'
    _type = 'Slider'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, defaultValue=Component.UNDEFINED, disabled=Component.UNDEFINED, ariaLabel=Component.UNDEFINED, min=Component.UNDEFINED, max=Component.UNDEFINED, step=Component.UNDEFINED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'ariaLabel', 'defaultValue', 'disabled', 'max', 'min', 'step', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'ariaLabel', 'defaultValue', 'disabled', 'max', 'min', 'step', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(Slider, self).__init__(**args)
